@@ -1,5 +1,7 @@
 import inspect
 import re
+import os
+from contextlib import contextmanager
 from functools import wraps
 from velocity.db import exceptions
 from velocity.db.core.transaction import Transaction
@@ -17,11 +19,12 @@ class Engine:
 
     MAX_RETRIES = 100
 
-    def __init__(self, driver, config, sql, connect_timeout=5):
+    def __init__(self, driver, config, sql, connect_timeout=5, schema_locked=False):
         self.__config = config
         self.__sql = sql
         self.__driver = driver
         self.__connect_timeout = connect_timeout
+        self.__schema_locked = schema_locked
 
     def __str__(self):
         return f"[{self.sql.server}] engine({self.config})"
@@ -205,6 +208,29 @@ class Engine:
     def sql(self):
         return self.__sql
 
+    @property
+    def schema_locked(self):
+        """Returns True if schema modifications are locked."""
+        return self.__schema_locked
+
+    def lock_schema(self):
+        """Lock schema to prevent automatic modifications."""
+        self.__schema_locked = True
+
+    def unlock_schema(self):
+        """Unlock schema to allow automatic modifications."""
+        self.__schema_locked = False
+
+    @contextmanager
+    def unlocked_schema(self):
+        """Temporarily unlock schema for automatic creation."""
+        original_state = self.__schema_locked
+        self.__schema_locked = False
+        try:
+            yield self
+        finally:
+            self.__schema_locked = original_state
+
     @property
     def version(self):
         """
@@ -353,12 +379,12 @@ class Engine:
         if sql:
             formatted_sql_info = f" sql={self._format_sql_with_params(sql, parameters)}"
 
-        logger.warning(
-            "Database error caught. Attempting to transform: code=%s message=%s%s",
-            error_code,
-            error_message,
-            formatted_sql_info,
-        )
+        # logger.warning(
+        #     "Database error caught. Attempting to transform: code=%s message=%s%s",
+        #     error_code,
+        #     error_message,
+        #     formatted_sql_info,
+        # )
 
         # Direct error code mapping
         if error_code in self.sql.ApplicationErrorCodes:
