@@ -4,10 +4,11 @@ import sqlparse
 from psycopg2 import sql as psycopg2_sql
 
 from velocity.db import exceptions
+from ..base.sql import BaseSQLDialect
 
 from .reserved import reserved_words
 from .types import TYPES
-from .operators import OPERATORS
+from .operators import OPERATORS, PostgreSQLOperators
 from ..tablehelper import TableHelper
 from collections.abc import Mapping, Sequence
 
@@ -61,7 +62,7 @@ system_fields = [
 ]
 
 
-class SQL:
+class SQL(BaseSQLDialect):
     server = "PostGreSQL"
     type_column_identifier = "data_type"
     is_nullable = "is_nullable"
@@ -95,7 +96,7 @@ class SQL:
     DataIntegrityErrorCodes = ["23503", "23502", "23514", "23P01", "22003"]
 
     @classmethod
-    def get_error(self, e):
+    def get_error(cls, e):
         error_code = getattr(e, "pgcode", None)
         error_mesg = getattr(e, "pgerror", None)
         return error_code, error_mesg
